﻿using Azure.Messaging.ServiceBus;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;

namespace ServiceBusTestCore
{
    public class Worker
    {
         internal async Task ReceiveMessagesAsync(string connectionString, string queueName)
        {
            await using (ServiceBusClient client = new ServiceBusClient(connectionString))
            {
                // create a processor that we can use to process the messages
                ServiceBusProcessor processor = client.CreateProcessor(queueName, new ServiceBusProcessorOptions());

                // add handler to process messages
                processor.ProcessMessageAsync += MessageHandler;

                // add handler to process any errors
                processor.ProcessErrorAsync += ErrorHandler;

                // start processing 
                await processor.StartProcessingAsync();

                Console.WriteLine("Wait for a minute and then press any key to end the processing");
                Console.ReadKey();

                // stop processing 
                Console.WriteLine("\nStopping the receiver...");
                await processor.StopProcessingAsync();
                Console.WriteLine("Stopped receiving messages");
            }
        }

        // handle received messages
         async Task MessageHandler(ProcessMessageEventArgs args)
        {
            string body = args.Message.Body.ToString();
           // Console.WriteLine($"Received: {body}");
            dynamic js = JsonConvert.DeserializeObject(body);

            Console.WriteLine($"{js["metaData"].vehicle.vin} : {js["metaData"].vehicle.vehicleId}");
            string xx = "xx";
            foreach (dynamic sp in js.resultData.seriesParts)
            {
                dynamic dpx = sp.dataPoints;
                var dp = dpx.Count > 0 ? dpx[0].value : xx;
                Console.WriteLine($"{sp.series.seriesName} : {dp}");
            }
            Console.WriteLine($"==================={DateTime.Now.ToLocalTime()}====================\n\n");
            // complete the message. messages is deleted from the queue. 
            await args.CompleteMessageAsync(args.Message);
        }

        // handle any errors when receiving messages
         Task ErrorHandler(ProcessErrorEventArgs args)
        {
            Console.WriteLine(args.Exception.ToString());
            return Task.CompletedTask;
        }
    }
}
